==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetEvaluationPlanScores.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[GetEvaluationPlanScores] (
	@VCC VARCHAR(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- CONSULTAMOS LOS SCORES RELACIONADOS AL PLAN
	SELECT HS.[ID]								'id',
			HS.[IdAbility]						'idAbility',
			HS.[Description]					'description',
			HS.[Value]				            'value'
		FROM [HistoricScore] HS (NOLOCK)
		WHERE [VCC] = @VCC
			AND [EvaluationPlanId] = @EvaluationPlanId
		ORDER BY Value DESC



	-- CONSULTAMOS LAS TIPIFICACIONES DE LAS HABILIDADES RELACIONADAS AL PLAN
	SELECT EFAST.[ScoreId]							'scoreId',
			EFAST.[ID]								'id',
			EFAST.[Description]						'description',
			EFAST.[Detail]							'detail',
			EFAST.[Order]							'order'
		FROM [dbo].[HistoricEvaluationFormatAbilityScoreTipification] EFAST (NOLOCK)
		WHERE EFAST.[VCC] = @VCC
			AND [EvaluationPlanId] = @EvaluationPlanId
		ORDER BY EFAST.[Order] ASC



	-- CONSULTAMOS LAS QUERY DE TIPIFICACION DE LAS HABILIDADES RELACIONADAS AL FORMATO
	SELECT CAST(HEFASTQ.[ScoreId] AS INT)			'scoreId',
			HEFASTQ.[TipificationId]				'tipificationId',
			HEFASTQ.[QueryId]						'queryId',
			HEFASTQ.[QueryContent]					'queryContent',
			HEFASTQ.[AcceptancePercentage]			'acceptancePercentage',
			HEFASTQ.[AcceptancePercentage] * 100	'acceptanceInteger'
		FROM [dbo].[HistoricEvaluationFormatAbilityScoreTipificationQuery] HEFASTQ (NOLOCK)
		WHERE HEFASTQ.[VCC] = @VCC
			AND HEFASTQ.[EvaluationPlanId] = @EvaluationPlanId



	-- CONSULTAMOS LOS ITEMS DE TIPIFICACIONES DE LAS HABILIDADES RELACIONADAS AL PLAN
	SELECT EFASTI.[ScoreId]							'scoreId',
			EFASTI.[TipificationId]					'tipificationId',
			EFASTI.[ID]								'id',
			EFASTI.[SecondLevelItemId]				'secondLevelItemId',
			EFASTI.[Description]					'description',
			EFASTI.[Order]							'order'
		FROM [dbo].[HistoricEvaluationFormatAbilityScoreTipificationItem] EFASTI (NOLOCK)
		WHERE EFASTI.[VCC] = @VCC
			AND [EvaluationPlanId] = @EvaluationPlanId
		ORDER BY EFASTI.[Order] ASC

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_7.8.2_database.tar.gz: database/mssql/procedures/GetEvaluationPlanScores.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[GetEvaluationPlanScores] (
	@VCC VARCHAR(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- CONSULTAMOS LOS SCORES RELACIONADOS AL PLAN
	SELECT DISTINCT HS.[ID]								'id',
			HS.[IdAbility]						'idAbility',
			HS.[Description]					'description',
			HS.[Value]				            'value'
		FROM [HistoricScore] HS (NOLOCK)
		WHERE [VCC] = @VCC
			AND [EvaluationPlanId] = @EvaluationPlanId
		ORDER BY Value DESC



	-- CONSULTAMOS LAS TIPIFICACIONES DE LAS HABILIDADES RELACIONADAS AL PLAN
	SELECT DISTINCT EFAST.[ScoreId]							'scoreId',
			EFAST.[ID]								'id',
			EFAST.[Description]						'description',
			EFAST.[Detail]							'detail',
			EFAST.[Order]							'order'
		FROM [dbo].[HistoricEvaluationFormatAbilityScoreTipification] EFAST (NOLOCK)
		WHERE EFAST.[VCC] = @VCC
			AND [EvaluationPlanId] = @EvaluationPlanId
		ORDER BY EFAST.[Order] ASC



	-- CONSULTAMOS LAS QUERY DE TIPIFICACION DE LAS HABILIDADES RELACIONADAS AL FORMATO
	SELECT DISTINCT CAST(HEFASTQ.[ScoreId] AS INT)			'scoreId',
			HEFASTQ.[TipificationId]				'tipificationId',
			HEFASTQ.[QueryId]						'queryId',
			HEFASTQ.[QueryContent]					'queryContent',
			HEFASTQ.[AcceptancePercentage]			'acceptancePercentage',
			HEFASTQ.[AcceptancePercentage] * 100	'acceptanceInteger'
		FROM [dbo].[HistoricEvaluationFormatAbilityScoreTipificationQuery] HEFASTQ (NOLOCK)
		WHERE HEFASTQ.[VCC] = @VCC
			AND HEFASTQ.[EvaluationPlanId] = @EvaluationPlanId



	-- CONSULTAMOS LOS ITEMS DE TIPIFICACIONES DE LAS HABILIDADES RELACIONADAS AL PLAN
	SELECT DISTINCT EFASTI.[ScoreId]							'scoreId',
			EFASTI.[TipificationId]					'tipificationId',
			EFASTI.[ID]								'id',
			EFASTI.[SecondLevelItemId]				'secondLevelItemId',
			EFASTI.[Description]					'description',
			EFASTI.[Order]							'order'
		FROM [dbo].[HistoricEvaluationFormatAbilityScoreTipificationItem] EFASTI (NOLOCK)
		WHERE EFASTI.[VCC] = @VCC
			AND [EvaluationPlanId] = @EvaluationPlanId
		ORDER BY EFASTI.[Order] ASC

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
